Learn R Programming

gdldata (version 0.1)

gdl_countries: Get country list

Description

Returns a list of countries available in the current dataset.

Usage

gdl_countries(session)

Value

A data frame containing a list of countries for the dataset.

Arguments

session

A valid GDL session object to interface with.

Examples

Run this code
if (FALSE) {
# Create a session using your API token (provided by environment here)
session <- gdl_session(Sys.getenv('GDL_API_TOKEN'))
# Request list of countries
countries <- gdl_countries(session)
head(countries, n=10)
}

Run the code above in your browser using DataLab