gdl_indicators: Get indicator list

View source: R/reference_funcs.R

gdl_indicatorsR Documentation

Get indicator list

Description

Returns the list of indicators available in the current dataset.

Usage

gdl_indicators(session)

Arguments

session

A valid GDL session object to interface with.

Value

A data frame containing a list of indicators for the dataset.

Examples

## Not run: 
# Create a session using your API token (provided by environment here)
session <- gdl_session(Sys.getenv('GDL_API_TOKEN'))
# Request list of available indicators for 'geos' dataset
indicators <- session |> set_dataset('geos') |> gdl_indicators()

## End(Not run)

gdldata documentation built on March 16, 2026, 5:06 p.m.