Learn R Programming

gdldata (version 0.1)

gdl_regions: Get region list

Description

Returns a list of regions available for a particular country.

Usage

gdl_regions(session, country)

Value

A data frame containing a list of regions for the country.

Arguments

session

A valid GDL session object to interface with.

country

An ISO3 country code.

Examples

Run this code
if (FALSE) {
# Create a session using your API token (provided by environment here)
session <- gdl_session(Sys.getenv('GDL_API_TOKEN'))
# Request list of regions for India
regions <- gdl_regions(session, 'IND')
head(regions, n=10)
}

Run the code above in your browser using DataLab